@@ -1,14 +1,10 @@
-# -*- coding: utf-8 -*-
 """AWS DynamoDB result store backend."""
-from __future__ import absolute_import, unicode_literals
-
 from collections import namedtuple
 from time import sleep, time
 
 from kombu.utils.url import _parse_url as parse_url
 
 from celery.exceptions import ImproperlyConfigured
-from celery.five import string
 from celery.utils.log import get_logger
 
 from .base import KeyValueStoreBackend
@@ -16,8 +12,8 @@ from .base import KeyValueStoreBackend
 try:
     import boto3
     from botocore.exceptions import ClientError
-except ImportError:  # pragma: no cover
-    boto3 = ClientError = None  # noqa
+except ImportError:
+    boto3 = ClientError = None
 
 __all__ = ('DynamoDBBackend',)
 
@@ -64,7 +60,7 @@ class DynamoDBBackend(KeyValueStoreBackend):
     _available_fields = None
 
     def __init__(self, url=None, table_name=None, *args, **kwargs):
-        super(DynamoDBBackend, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         self.url = url
         self.table_name = table_name or self.table_name
@@ -97,7 +93,7 @@ class DynamoDBBackend(KeyValueStoreBackend):
 
             if region == 'localhost':
                 # We are using the downloadable, local version of DynamoDB
-                self.endpoint_url = 'http://localhost:{}'.format(port)
+                self.endpoint_url = f'http://localhost:{port}'
                 self.aws_region = 'us-east-1'
                 logger.warning(
                     'Using local-only DynamoDB endpoint URL: {}'.format(
@@ -132,7 +128,7 @@ class DynamoDBBackend(KeyValueStoreBackend):
                     self.time_to_live_seconds = int(ttl)
                 except ValueError as e:
                     logger.error(
-                        'TTL must be a number; got "{ttl}"',
+                        f'TTL must be a number; got "{ttl}"',
                         exc_info=e
                     )
                     raise e
@@ -205,28 +201,25 @@ class DynamoDBBackend(KeyValueStoreBackend):
         """Create table if not exists, otherwise return the description."""
         table_schema = self._get_table_schema()
         try:
-            table_description = self._client.create_table(**table_schema)
-            logger.info(
-                'DynamoDB Table {} did not exist, creating.'.format(
-                    self.table_name
-                )
-            )
-            # In case we created the table, wait until it becomes available.
-            self._wait_for_table_status('ACTIVE')
-            logger.info(
-                'DynamoDB Table {} is now available.'.format(
-                    self.table_name
-                )
-            )
-            return table_description
+            return self._client.describe_table(TableName=self.table_name)
         except ClientError as e:
             error_code = e.response['Error'].get('Code', 'Unknown')
 
-            # If table exists, do not fail, just return the description.
-            if error_code == 'ResourceInUseException':
-                return self._client.describe_table(
-                    TableName=self.table_name
+            if error_code == 'ResourceNotFoundException':
+                table_description = self._client.create_table(**table_schema)
+                logger.info(
+                    'DynamoDB Table {} did not exist, creating.'.format(
+                        self.table_name
+                    )
                 )
+                # In case we created the table, wait until it becomes available.
+                self._wait_for_table_status('ACTIVE')
+                logger.info(
+                    'DynamoDB Table {} is now available.'.format(
+                        self.table_name
+                    )
+                )
+                return table_description
             else:
                 raise e
 
@@ -480,14 +473,14 @@ class DynamoDBBackend(KeyValueStoreBackend):
         return self._get_client()
 
     def get(self, key):
-        key = string(key)
+        key = str(key)
         request_parameters = self._prepare_get_request(key)
         item_response = self.client.get_item(**request_parameters)
         item = self._item_to_dict(item_response)
         return item.get(self._value_field.name)
 
     def set(self, key, value):
-        key = string(key)
+        key = str(key)
         request_parameters = self._prepare_put_request(key, value)
         self.client.put_item(**request_parameters)
 
@@ -495,6 +488,6 @@ class DynamoDBBackend(KeyValueStoreBackend):
         return [self.get(key) for key in keys]
 
     def delete(self, key):
-        key = string(key)
+        key = str(key)
         request_parameters = self._prepare_get_request(key)
         self.client.delete_item(**request_parameters)
