@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
 """Worker name utilities."""
-from __future__ import absolute_import, unicode_literals
-
 import os
 import socket
 from functools import partial
@@ -87,7 +84,7 @@ def node_format(s, name, **extra):
 def _fmt_process_index(prefix='', default='0'):
     from .log import current_process_index
     index = current_process_index()
-    return '{0}{1}'.format(prefix, index) if index else default
+    return f'{prefix}{index}' if index else default
 
 
 _fmt_process_index_with_prefix = partial(_fmt_process_index, '-', '')
